reuse-lint-file - reuse 6.1.2 documentation

Skip to content
Back to top
View this page

# reuse-lint-file

## Synopsis

reuse lint-file [options] [file …]

## Description

reuse-lint-file verifies whether the specified files are compliant with the REUSE Specification located at https://reuse.software/spec. It runs the linter from reuse-lint(1) against a subset of files, using a subset of criteria.

Files that are ignored by reuse-lint are also ignored by reuse-lint-file, even if specified.

## Criteria

The criteria are the same as used in reuse-lint(1), but using only a subset:

- Missing licenses.

- Read errors.

- Files without copyright and license information.

## Options

-q, --quiet

  Do not print anything to STDOUT.

-l, --lines

  Output one line per error, prefixed by the file path. This option is the default.

--help

  Display help and exit.